package com.rsjst.hcm.recruit.biz.controller;

import cn.zgfxrc.boot.common.core.entity.interfaces.AddGroup;
import cn.zgfxrc.boot.common.core.entity.interfaces.DelGroup;
import cn.zgfxrc.boot.common.core.entity.interfaces.EditGroup;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.rsjst.hcm.recruit.api.entity.RecruitPositionPojo;
import com.rsjst.hcm.recruit.biz.service.RecruitPositionService;
import com.seepine.secret.annotation.Log;
import com.seepine.secret.annotation.Permission;
import com.seepine.wrap.WrapException;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import java.util.List;
import lombok.AllArgsConstructor;
import org.springframework.lang.Nullable;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author wangjx
 * @data 2025.2.21
 */
@RestController
@Api(tags = "职位管理")
@RequestMapping("recruit/position")
@AllArgsConstructor
public class RecruitPositionController {
  RecruitPositionService service;

  /**
   * 分页查询
   *
   * @param page 分页对象
   * @param entity 实体类
   * @return IPage
   */
  @PostMapping("page/res")
  @Permission("recruit_position_view")
  public IPage<RecruitPositionPojo> pageRes(
      Page<RecruitPositionPojo> page, @RequestBody RecruitPositionPojo entity) {
    return service.pageRes(page, entity);
  }

  /**
   * 分页查询
   *
   * @param entity 实体类
   * @return List
   */
  @ApiOperation("获取数组")
  @PostMapping("list")
  @Permission("recruit_position_view")
  public List<RecruitPositionPojo> list(@RequestBody @Nullable RecruitPositionPojo entity) {
    LambdaQueryWrapper<RecruitPositionPojo> wrapper = Wrappers.lambdaQuery(entity);
    return service.list(wrapper);
  }

  /**
   * 新增
   *
   * @param entity 实体类
   */
  @Log("新增")
  @ApiOperation("新增")
  @PostMapping("add")
  @Permission("recruit_position_add")
  public void save(@RequestBody @Validated(AddGroup.class) RecruitPositionPojo entity) {
    if (!service.save(entity)) {
      throw new WrapException("保存失败");
    }
  }

  /**
   * 修改
   *
   * @param entity 实体类
   */
  @Log("修改")
  @ApiOperation("修改")
  @PostMapping("edit")
  @Permission("recruit_position_edit")
  public void updateById(@RequestBody @Validated(EditGroup.class) RecruitPositionPojo entity) {
    if (!service.updateById(entity)) {
      throw new WrapException("修改失败");
    }
  }

  /**
   * 通过id删除
   *
   * @param entity 实体类
   */
  @Log("删除")
  @ApiOperation("根据id删除")
  @PostMapping("del")
  @Permission("recruit_position_del")
  public void removeById(
      @ApiParam("主键") @RequestBody @Validated(DelGroup.class) RecruitPositionPojo entity) {
    if (!service.removeById(entity.getId())) {
      throw new WrapException("删除失败");
    }
  }
}
